# arpes.plotting.dos module

**arpes.plotting.dos.plot\_dos(data, title=None, out=None, norm=None,
dos\_pow=1,**kwargs)\*\*

**arpes.plotting.dos.plot\_core\_levels(data, title=None, out=None,
norm=None, dos\_pow=1, core\_levels=None, binning=1,
promenance=5,**kwargs)\*\*
